{{/* vim: set filetype=mustache: */}}

{{/* Truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec) */}}
{{/* Name */}}
{{- define "app.name" -}}
{{- default .Release.Name | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Namespace */}}
{{- define "app.namespace" -}}
{{- default .Release.Namespace | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Version */}}
{{- define "app.version" -}}
{{- default .Chart.Version | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Chart: Name + Version */}}
{{- define "app.chart" -}}
{{ printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end -}}

{{/* Managed-by -> On Helm, this value is always Helm */}}
{{- define "app.managedBy" -}}
{{- default .Release.Service | toString | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/* Default Labels: Helm recommended best-practice labels https://helm.sh/docs/chart_best_practices/labels/ */}}
{{- define "app.defaultLabels" }}
app.kubernetes.io/instance: user-manager
app.kubernetes.io/managed-by: {{ include "app.managedBy" . }}
app.kubernetes.io/name: {{ include "app.name" . }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
app.kubernetes.io/part-of: ozgcloud
app.kubernetes.io/version: {{ include "app.version" . }}
helm.sh/chart: {{ include "app.chart" . }}
{{- end -}}

{{- define "app.matchLabels" }}
app.kubernetes.io/name: {{ include "app.name" . }}
app.kubernetes.io/namespace: {{ include "app.namespace" . }}
{{- end -}}

{{- define "app.imagePullSecret" }}
{{- with .Values.imageCredentials }}
{{- printf "{\"auths\":{\"%s\":{\"username\":\"%s\",\"password\":\"%s\",\"email\":\"%s\",\"auth\":\"%s\"}}}" .registry .username .password .email (printf "%s:%s" .username .password | b64enc) | b64enc }}
{{- end }}
{{- end }}

{{- define "app.cronjobScheduler" }}
{{- printf "%d %d * * *" (div (randNumeric 2) 2) (div (randNumeric 1) 2) -}}
{{- end -}}

{{- define "app.ozgcloudEnvironment" -}}
{{- required "Environment muss angegeben sein" (.Values.ozgcloud).environment -}}
{{- end -}}

{{- define "app.ssoServerUrl" -}}
{{- if contains "https://" .Values.sso.serverUrl -}}
{{- .Values.sso.serverUrl -}}
{{- else -}}
{{- printf "https://%s" .Values.sso.serverUrl -}}
{{- end -}}
{{- end -}}

{{- define "app.ozgcloudBundesland" -}}
{{- required "ozgcloud.bundesland must be set " (.Values.ozgcloud).bundesland }}
{{- end -}}

{{- define "app.ozgcloudBezeichner" -}}
{{- if (.Values.ozgcloud).bezeichner -}}

{{ $length := len (.Values.ozgcloud).bezeichner }}
{{- if lt 27 $length -}}
{{ required (printf "Bezeichner %s ist zu lang (max. 27 Zeichen)" (.Values.ozgcloud).bezeichner) nil }}
{{- else -}}
{{- required "Bezeichner muss angegeben sein" (.Values.ozgcloud).bezeichner -}}
{{- end -}}
{{- else -}}
{{- required "Bezeichner muss angegeben sein" (.Values.ozgcloud).bezeichner -}}
{{- end -}}
{{- end -}}

{{- define "app.ssoRealm" -}}
{{ printf "%s-%s-%s" (include "app.ozgcloudBundesland" .) ( include "app.ozgcloudBezeichner" . ) ( include "app.ozgcloudEnvironment" . ) | trunc 63 | trimSuffix "-" }}
{{- end -}}

{{- define "app.ssoClientName" -}}
{{- if (.Values.sso).client_name -}}
{{ printf "%s" (.Values.sso).client_name }}
{{- else -}}
{{ printf "alfa" }}
{{- end -}}
{{- end -}}

{{- define "app.baseUrl" -}}
{{ printf "https://%s-%s.%s" (include "app.ozgcloudBezeichner" .) (include "app.name" .) .Values.baseUrl }}
{{- end -}}

{{- define "app.alfaAddress" -}}
{{ printf "https://%s.%s" (include "app.ozgcloudBezeichner" .) .Values.baseUrl }}
{{- end -}}

{{- define "app.replaceAllNonAlphanumeric" -}}
{{- regexReplaceAll "[^a-zA-Z0-9]" . "" }}
{{- end -}}

{{- define "app.generateKeycloakUserRessourceName" -}}
{{- $lowerUserName := .Values.sso.api_user.name | lower }}
{{- $alphanumericUserName :=  (include "app.replaceAllNonAlphanumeric" $lowerUserName ) }}
{{- printf "%s-keycloak-user"  ( $alphanumericUserName | trunc 20) }}
{{- end -}}

{{- define "app.generateKeycloakUserSecretName" -}}
{{- $lowerUserName := .Values.sso.api_user.name | lower }}
{{- $alphanumericUserName :=  (include "app.replaceAllNonAlphanumeric" $lowerUserName ) }}
{{- printf "%s-credentials"  ( $alphanumericUserName | trunc 20) }}
{{- end -}}

{{- define "app.databaseSecretName" -}}
{{- if (.Values.database).secretName -}}
{{  .Values.database.secretName }}
{{- else -}}
{{  printf "ozg-mongodb-admin-user-manager-user" }}
{{- end -}}
{{- end -}}

{{- define "app.databaseName" -}}
{{- if (.Values.database).databaseName -}}
{{  .Values.database.databaseName }}
{{- else -}}
{{ printf "user-manager-database" }}
{{- end -}}
{{- end -}}