/*
 * Copyright (C) 2022-2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.user.sync;

import java.util.function.Predicate;

import org.apache.commons.collections4.CollectionUtils;

import de.ozgcloud.common.logging.OzgCloudLogging;
import de.ozgcloud.user.User;
import de.ozgcloud.user.UserService;
import de.ozgcloud.user.keycloak.KeycloakUserRemoteService;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;

@ApplicationScoped
@OzgCloudLogging
class SyncService {

	private final Predicate<User> HAS_ANY_ROLE = user -> CollectionUtils.isNotEmpty(user.getRoles());// NOSONAR

	@Inject
	UserService userService;
	@Inject
	KeycloakUserRemoteService keycloakService;

	void sync(long syncTimestamp) {
		keycloakService.getAllUsers()
				.filter(HAS_ANY_ROLE)
				.forEach(user -> userService.saveAndSync(addLastSyncTimestamp(user, syncTimestamp)));

		userService.markUnsyncedUsersAsDeleted(syncTimestamp);
	}

	User addLastSyncTimestamp(User user, long syncTimestamp) {
		return user.toBuilder().lastSyncTimestamp(syncTimestamp).build();
	}

}